
<template>
  <a-modal
    :title="title"
    :width="700"
    :visible="visible"
    :maskClosable="false"
    :confirmLoading="confirmLoading"
    :okButtonProps="{ props: {disabled: disableSubmit} }"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >
    <a-spin :spinning="confirmLoading">
      <a-form :form="form">
        <a-row style="width: 100%">
          <a-col :span="12">
            <a-form-item
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              label="危险源选择"
            >
              <a-input-search
               enter-button
                @search="onSearchRiskPreventionName"
                placeholder="请选择危险源"
                v-decorator="['riskPreventionNum',validatorRules.riskPreventionNum]"
                :read-only="true"
               />
            </a-form-item>
          </a-col>
          <a-col :span="24/2" >
            <a-form-item label="危险名称" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input :disabled="true" v-decorator="['riskPreventionName', validatorRules.riskPreventionName]" placeholder="请输入危险名称" ></a-input>
            </a-form-item>
          </a-col>
          <a-col :span="24/2" >
            <a-form-item label="危险描述" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input :disabled="true"  v-decorator="['riskPreventionDescription', validatorRules.riskPreventionDescription]" placeholder="请输入危险描述" ></a-input>
            </a-form-item>
          </a-col>
          <a-col :span="24/2" >
            <a-form-item label="防控方式" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input :disabled="true" v-decorator="['measure', validatorRules.measure]" placeholder="请输入防控方式" ></a-input>
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>

    <template slot="footer">
      <a-button
        :style="{marginRight: '8px'}"
        @click="handleCancel"
      >
        关闭
      </a-button>
      <a-button
        :disabled="disableSubmit || confirmLoading"
        :loading="confirmLoading"
        @click="handleOk"
        type="primary"
      >确定</a-button>
    </template>

    <prevention-risk-select
    ref="riskPrevention"
    @sendRiskPrevention="sendRiskPrevention"
    >
    </prevention-risk-select>

  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { postAction, requestPut } from '@/api/manage'
import { duplicateCheck } from '@/api/api'
import PreventionRiskSelect from './moudles/select/PreventionRiskSelect.vue'


export default {
  name: 'riskPreventionModel',
  components: {
    PreventionRiskSelect
  },
  props:{
    mainId:{
        type:String,
        required:false,
        default:''
      }
  },
  data() {
    return {
      title: "操作",
      visible: false,
      codeDisable: true,
      disableSubmit: false,
      maintenanceStandardId: '',
      riskPreventionId: '',
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 6 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 18 },
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        riskPreventionName: {
          rules: [
            { required: true, message: '请选择物料!' },
          ]
        },
      },
      url: {
        add: "/eam/repairOrder/addRepairOrderRiskPrevention",
        edit: "/eam/repairOrder/editRepairOrderRiskPrevention"
      },
      //新增、编辑、删除、批量删除操作改变数据后刷新关联的组件的监听属性
      alterFlag: "",
    }
  },
  created() {
  },
  methods: {

    add() {
      this.edit({});
    },

    edit(record) {
      this.form.resetFields();
      this.model = Object.assign({}, record);
      this.visible = true;
      this.disableSubmit = false;
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model,
          'riskPreventionNum',
          'riskPreventionName',
          'riskPreventionDescription',
          'measure'));
      });
      if (record.id) {
        this.codeDisable = true;
      } else {
        this.codeDisable = false;
      }
    },

    close() {
      this.$emit('close');
      this.visible = false;
    },

    //保存并新增按钮触发


    handleOk() {
      const that = this;
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let formData = Object.assign(this.model, values);
          formData.repairOrderId = this.mainId;
          formData.riskPreventionId = this.riskPreventionId
          let obj;
          if (!this.model.id) {
            obj = postAction(this.url.add, formData);
          } else {
            obj = requestPut(this.url.edit, formData, { id: this.model.id });
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
              that.alterFlag = new Date();
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },

    onSearchRiskPreventionName() {
      this.$refs.riskPrevention.list();
      this.$refs.riskPrevention.title = "危险源选择";
    },
    sendRiskPrevention(data) {
      let record = data.record;
      this.riskPreventionId = record.id;
      this.form.setFieldsValue({ riskPreventionNum: record.num,riskPreventionName: record.name,riskPreventionDescription:record.description,measure:record.measure });
    },

    handleCancel() {
      this.close()
    },

  },
}
</script>

<style scoped>
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>
